Opaque FSST symbol table.
Build tables with FSST.train/2 or FSST.Table.from_symbols/1 and pass them
to FSST.compress/3 and FSST.decompress/3.
Summary
Functions
Builds a pure Elixir table from an existing serialized FSST symbol table.
Builds a pure Elixir table from existing serialized symbols or raises.
Types
Functions
Builds a pure Elixir table from an existing serialized FSST symbol table.
Symbols must be provided in code order. Each symbol must be a binary from one
to eight bytes. Code 255 is reserved for escaped raw bytes, so at most 255
symbols are allowed.
Builds a pure Elixir table from existing serialized symbols or raises.